<div class="container" style="display: flex; align-items: center; justify-content: space-between; max-width: 70%; min-width: 400px ; margin: 0 auto; padding: 10px 0 15px 0; border-bottom: 1px solid">
    <div class="image-container" style="flex: 1; padding: 0 0 0 10px;">
        <img src="" alt="wavesongs logo" style="max-width: 100%; height: auto; display: block;">
    </div>
    <div class="text-container" style="flex: 2;">
        <h1 style="margin: 0; padding: 0 0 5px 0; border-bottom: 0">WaveSongs</h1>
        <p style="margin: 0; padding: 5px 0 0 0;">A python package for birdsongs creation and data extraction</p>
    </div>
</div>


<div align='center' style="margin: 20px 0 0px 0">

![version](https://img.shields.io/badge/version-1.0.0-008000)
![PyPI status](https://img.shields.io/pypi/status/ansicolortags.svg)
[![License: GPL v3](https://img.shields.io/badge/license-GPLv3-blue.svg)](https://www.gnu.org/Licenses/gpl-3.0)
![Open Source Love](https://img.shields.io/badge/open%20source-♡-lightgrey)
![Python 3.10](https://img.shields.io/badge/python->=3.10%20-blue.svg)
<!-- [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/wavesongs/wavesongs/HEAD?urlpath=%2Fdoc%2Ftree%2Ftest.ipynb) -->

[Overview](#overview) •
[Installation](#installation) •
[Getting Started](#getting-started) •
[References](#references)
</div>

## 🔎 Overview

This package contains the python implementation of the [motor gestures model for birdsongs](http://www.lsd.df.uba.ar/papers/simplemotorgestures.pdf) developed by [Gabo Mindlin](https://scholar.google.com.ar/citations?user=gMzZPngAAAAJ&hl=en). The comparable synthetic birdsongs are generated by solving a minimization problem with the fundamental frequency (FF) and spectral content index (SCI) as parameteres. The sound analysis is performed with [librosa](https://librosa.org/) and the optimization problem is solved using [scipy.optimize](https://docs.scipy.org/doc/scipy/tutorial/optimize.html). 

The model implementation is tested with the species Zonotrichia Capensis, Ocellated Tapaculo, and Mimus Gilvus. The results obtained achived a relative error lower than 5 % respecto to the FF for the Zonotrichia Capensis samples.

## ⚒️ Installation

### Requirments

`wavesong` is tested in Python 3.10 and work for higher versions. 


First of all, clone the the **wavesongs** repository and enter to it.

```bat
git clone https://github.com/wavesongs/wavesongs
cd wavesongs
```


### Environment

Create an evironment for the project and activate it.

#### Python

```bash
sudo apt install python3-venv    # install virtual environments
python3 -m venv ./venv           # create venv
source ./venv/bin/activate       # activate venv
```

If you are working on Windows, activate the venv with ```source /venv/bin/Activate```.

#### Conda

```bash
conda create -n wavesongs python=3.12
conda activate wavesongs
```

<!-- #### Docker

In process...

```bash
docker build --tag wavesongs .
docker run --detach wavesongs
``` -->

### WaveSongs

The required libraries are listed in the [requirements.txt](./requirements.txt) file. To install them execute

```bash
pip install -r requirements.txt
```

Next, install wavesongs, add it to the environment


```bash
pip install -e .
``` 

<!-- 
1. `pip`:

2. [`poetry`](https://python-poetry.org/):


    ```bat
    sudo apt update
    sudo apt install pipx
    pipx ensurepath
    ```

    You can install poetry with `pipx install poetry`. For more information visit [Installing pipx](https://pipx.pypa.io/stable/installation/#installing-pipx). 
    
    Finally, install **wavesongs**

    ```bat
    poetry install
    ```

    Reset the kernel or IDE. -->

## 💪 Getting Started

See the [tutorial](./Tutorial.ipynb) for the use guide. 




If you want to know more about the physical modeling, constans details, ff algorithm, etc, visit the [documentation](./).

## 🎶 Datasets

The evaluated audio samples are downloaded from [Xeno Canto](https://xeno-canto.org/) and [eBird](https://ebird.org/home). However, you can record and import your own songs.

## 📜 License

The project is licensed under the [GNU General Public License v3.0](./LICENSE).

## 📒 Citation

If you use `wavesongs` in your own work, please cite the associated article and/or the repository:

```bibtex
@software{san_wavesongs_2025,
    author = {Aguilera Novoa, Sebastian},
    month = feb,
    title = {wavesongs},
    url = {https://github.com/wavesongs/wavesongs/},
    version = {1.0.0},
    year = {2025}
}
```

## 📝 To Do

- [] Donwload data from xeno canto
- [] Rois maad
- [] Change FF parametrization 


## 📚 References

### Literature

1. Amador, A., Perl, Y. S., Mindlin, G. B., & Margoliash, D. (2013). Elemental 
5. gesture dynamics are encoded by song premotor cortical neurons. *Nature*, 495(7439), 59–64. [doi:10.1038/nature11967](https://doi.org/10.1038/nature11967)  

2. Mindlin, G., & Laje, R. (2005). The Physics of Birdsong. *The Physics of Birdsong: Biological and Medical Physics, Biomedical Engineering*. Springer-Verlag Berlin Heidelberg. [doi:10.1007/3-540-28249-1](https://doi.org/10.1007/3-540-28249-1)

### Datasets

3. Xeno-canto Foundation and Naturalis Biodiversity Center (2005). xeno-canto: Sharing bird sounds from around the world.  

4. The Cornell Lab of Ornithology (2005). Macaulay Library - eBird. [ebird.com](https://ebird.com)

### Software

5. McFee, B., Raffel, C., Liang, D., Ellis, D. P., McVicar, M., Battenberg, E., & Nieto, O. (2015). [librosa](https://librosa.org/): Audio and music signal analysis in Python. *Proceedings of the 14th Python in Science Conference*, 8.  

6. Virtanen, P., Gommers, R., Oliphant, T. E., et al. (2020). SciPy 1.0: Fundamental Algorithms for Scientific Computing in Python. *Nature Methods*, 17, 261–272. [doi:10.1038/s41592-019-0686-2](https://doi.org/10.1038/s41592-019-0686-2)  
[Read online](https://rdcu.be/b08Wh)

7. Ulloa, J. S., Haupert, S., Latorre, J. F., Aubin, T., & Sueur, J. (2021). scikit-maad: An open-source and modular toolbox for quantitative soundscape analysis in Python. *Methods in Ecology and Evolution*, 12(12), 2334–2340. [doi:10.1111/2041-210X.13711](https://doi.org/10.1111/2041-210X.13711)  
